@@ -40,7 +40,7 @@ VERSION_1 = '1.0.0'
 VERSION_1_1 = '1.1.0'
 VERSION_1_2 = '1.2.0'
 VERSION_2_0 = '2.0.0'
-VERSION_3_0 = '3.0.26'
+VERSION_3_0 = '3.0.27'
 
 # For a new release, define a new constant and assign it to LAST_VERSION
 # The existing one has to be added to OLD_VERSIONS list.
@@ -70,6 +70,9 @@ SCIPION_HOME_VAR = 'SCIPION_HOME'
 SCIPION_TESTS = 'SCIPION_TESTS'
 SCIPION_SCRATCH = 'SCIPION_SCRATCH'
 
+# FONT
+SCIPION_DEFAULT_FONT_SIZE = 10
+
 # NOTES CONSTANTS
 SCIPION_NOTES_FILE = 'SCIPION_NOTES_FILE'
 SCIPION_NOTES_FILE_DEFAULT = 'notes.txt'
@@ -122,15 +125,18 @@ PROJECT_SETTINGS = 'settings.sqlite'
 
 class DOCSITEURLS:
     """Documentation site URL useful when exceptions happens and you want to point to some pages"""
-    HOME = 'https://scipion-em.github.io/docs/'
+    HOME = 'https://scipion-em.github.io/docs/release-3.0.0/'
     DOCS = HOME + 'docs/'
     CONFIG = DOCS + 'scipion-modes/scipion-configuration.html'
     CONFIG_SECTION = CONFIG + '#%s'
     CONTACTUS = 'http://scipion.i2pc.es/contact'
     USER = DOCS + 'user/'
+    GUI = USER + 'scipion-gui.html'
+    WAIT_FOR = GUI + '#waiting-for-other-protocols'
     PLUGIN_MANAGER = USER + 'plugin-manager.html'
     HOST_CONFIG = DOCS + "scipion-modes/host-configuration.html"
 
+
 # tkinter bind constants
 class TK:
     LEFT_CLICK = '<Button-1>'
