@@ -469,9 +469,8 @@ class ProtocolTreeConfig:
 
         # Read the protocols.conf of any installed plugin
         pluginDict = domain.getPlugins()
-        pluginList = cls.__orderByPriority(pluginDict.keys(),
-                                           priorityPluginList=Config.getPriorityPackageList())
-        for pluginName in pluginList:
+
+        for pluginName in pluginDict.keys():
             try:
 
                 # if the plugin has a path
@@ -518,14 +517,6 @@ class ProtocolTreeConfig:
         node.visible = anyLeaf
 
         return anyLeaf
-    @classmethod
-    def __orderByPriority(cls, pluginList, priorityPluginList):
-        if priorityPluginList:
-            sortedPluginList = priorityPluginList + [pluginName for pluginName in pluginList
-                                                     if pluginName not in priorityPluginList]
-            return sortedPluginList
-        else:
-            return pluginList
 
 
 class ProtocolConfig(MenuConfig):
