@@ -26,6 +26,8 @@
 # *  e-mail address 'scipion@cnb.csic.es'
 # *
 # **************************************************************************
+import logging
+logger = logging.getLogger(__name__)
 import glob
 import os
 import importlib
@@ -41,6 +43,7 @@ import pyworkflow as pw
 import pyworkflow.utils as pwutils
 import pyworkflow.object as pwobj
 from pyworkflow.template import Template
+from pyworkflow.utils import sortListByList
 
 from .constants import *
 
@@ -83,7 +86,7 @@ class Domain:
             bib = cls.__getSubmodule(name, 'bibtex')
             if bib is not None:
                 if hasattr(bib, "_bibtex"):
-                    print("WARNING FOR DEVELOPERS:  %s/%s._bibtex unnecessarily declared. Just the doc string is enough." % (name, "bibtex"))
+                    logger.info("WARNING FOR DEVELOPERS:  %s/%s._bibtex unnecessarily declared. Just the doc string is enough." % (name, "bibtex"))
                 else:
                     try:
                         m._bibtex = pwutils.LazyDict(lambda: pwutils.parseBibTex(bib.__doc__))
@@ -92,11 +95,15 @@ class Domain:
             cls._plugins[name] = m  # Register the name to as a plugin
 
         # Catch any import exception, warn about it but continue.
+        except ModuleNotFoundError:
+            # This is probably due to a priority package like pwchem not being installed
+            pass
         except Exception as e:
-            print(pwutils.yellow("WARNING!!: Plugin containing module %s does not import properly. "
+
+            (pwutils.yellow("WARNING!!: Plugin containing module %s does not import properly. "
                                  "All its content will be missing in this execution." % name))
-            print("Please, contact developers at %s and send this ugly information bellow. They'll understand it!." % DOCSITEURLS.CONTACTUS)
-            print(pwutils.yellow(traceback.format_exc()))
+            logger.info("Please, contact developers at %s and send this ugly information below. They'll understand it!." % DOCSITEURLS.CONTACTUS)
+            logger.info(pwutils.yellow(traceback.format_exc()))
 
     @classmethod
     def getPlugins(cls):
@@ -109,8 +116,17 @@ class Domain:
 
     @classmethod
     def _discoverPlugins(cls):
+        # Get the list of plugins registered
+        plugin_modules = []
         for entry_point in pkg_resources.iter_entry_points('pyworkflow.plugin'):
-            cls.registerPlugin(entry_point.name)
+            plugin_modules.append(entry_point.name)
+
+        # Sort the list taking into account the priority
+        plugin_modules = sortListByList(plugin_modules, pw.Config.getPriorityPackageList())
+
+        for module in plugin_modules:
+            cls.registerPlugin(module)
+
 
     @classmethod
     def _discoverGUIPlugins(cls):
@@ -194,7 +210,7 @@ class Domain:
                             if name in subclasses:
                                 # Get already added class plugin
                                 pluginCollision = subclasses[name]._package.__name__
-                                print("ERROR: Name collision (%s) detected "
+                                logger.info("ERROR: Name collision (%s) detected "
                                       "while discovering %s.%s.\n"
                                       " It conflicts with %s" %
                                       (name, pluginName, submoduleName,
@@ -353,11 +369,10 @@ class Domain:
                                                   doRaise=True)
                 viewers.append(prefViewer)
             except Exception as e:
-                print("Couldn't load \"%s\" as preferred viewer for %s.\n"
+                logger.error("Couldn't load \"%s\" as preferred viewer for %s.\n"
                       "There might be a typo in your VIEWERS variable "
                       "or an error in the viewer's plugin installation"
-                      % (prefViewerStr, className))
-                print(e)
+                      % (prefViewerStr, className), exc_info=e)
         return viewers
 
     @classmethod
@@ -407,11 +422,11 @@ class Domain:
     def printInfo(cls):
         """ Simple function (mainly for debugging) that prints basic
         information about this Domain. """
-        print("Domain: %s" % cls._name)
-        print("     objects: %s" % len(cls._objects))
-        print("   protocols: %s" % len(cls._protocols))
-        print("     viewers: %s" % len(cls._viewers))
-        print("     wizards: %s" % len(cls._wizards))
+        logger.info("Domain: %s" % cls._name)
+        logger.info("     objects: %s" % len(cls._objects))
+        logger.info("   protocols: %s" % len(cls._protocols))
+        logger.info("     viewers: %s" % len(cls._viewers))
+        logger.info("     wizards: %s" % len(cls._wizards))
 
     # ---------- Private methods of Domain class ------------------------------
     @staticmethod
@@ -454,7 +469,7 @@ class Domain:
         if doRaise:
             raise Exception("\n\n" + raiseMsg)
         else:
-            print(raiseMsg)
+            logger.info(raiseMsg)
 
     @staticmethod
     def __getSubmodule(name, subname):
@@ -521,7 +536,7 @@ class Plugin:
         if cls._condaActivationCmd is None:
             condaActivationCmd = os.environ.get(CONDA_ACTIVATION_CMD_VAR, "")
             if not condaActivationCmd:
-                print("WARNING!!_condaActivationCmd: %s variable not defined. "
+                logger.info("WARNING!!_condaActivationCmd: %s variable not defined. "
                       "Relying on conda being in the PATH" % CONDA_ACTIVATION_CMD_VAR)
             elif condaActivationCmd[-1] not in [";", "&"]:
                 condaActivationCmd += "&&"
@@ -604,7 +619,7 @@ class Plugin:
             missing = ["%s: %s" % (var, cls.getVar(var))
                        for var in cls._pathVars if not os.path.exists(cls.getVar(var))]
 
-            return (["Missing paths: the variables bellow point to non existing paths."]
+            return (["Missing paths: the variables below point to non existing paths."]
                     + missing + [
                      "Either install the software ( %s )" % DOCSITEURLS.PLUGIN_MANAGER,
                     "or edit the config file ( %s )" % DOCSITEURLS.CONFIG]) if missing else []
@@ -653,7 +668,7 @@ class PluginInfo:
             tuples = message_from_string('\n'.join(lines))
 
         except Exception:
-            print("Plugin %s seems is not a pip module yet. "
+            logger.info("Plugin %s seems is not a pip module yet. "
                   "No metadata found" % name)
             tuples = message_from_string('Author: plugin in development mode?')
 
